@@ -23,9 +23,9 @@ class ImageResampler(object):
         if output_spacing is None:
             output_spacing = ref_resampling_handle.GetSpacing()
         self.Resampler.SetOutputSpacing(output_spacing)
-        if interpolator is 'Linear':
+        if interpolator == 'Linear':
             self.Resampler.SetInterpolator(sitk.sitkLinear)
-        elif interpolator is 'Nearest':
+        elif interpolator == 'Nearest':
             self.Resampler.SetInterpolator(sitk.sitkNearestNeighbor)
         if ref_resampling_handle is not None:
             self.Resampler.SetOutputDirection(ref_resampling_handle.GetDirection())
@@ -38,6 +38,8 @@ class ImageResampler(object):
             new_size = np.ceil(new_size).astype(np.int)  # Image dimensions are in integers
             new_size = [np.int(i) for i in new_size]
             self.Resampler.SetSize(new_size)
+            self.Resampler.SetOutputDirection(input_image_handle.GetDirection())
+            self.Resampler.SetOutputOrigin(input_image_handle.GetOrigin())
         output = self.Resampler.Execute(input_image_handle)
         return output
 
